@@ -1,76 +1,60 @@
 # :Author: SAKIMA Kimihisa
 # :Contact: sakima at hooktail.org
-# :Date: $Date: 2006/01/25 17:25:16 $
-# :Revision: $Revision: 1.7 $
+# :Date: $Date: 2007/02/24 14:46:57 $
+# :Revision: $Revision: 1.9 $
 
 $KCODE = "EUC" 
 require 'digest/md5'
 
-
-# ==========================================================
-# 饤$...$ִ᥽å
-# ==========================================================
+# 饤$...$ˡ¾ִ
 def inline_math(buf)
+  buf.gsub!(/\\\$/, " <dollar> ")  # \$  <dollar> ִ
   
-  #  \$  <dollar> ִ$ΤΤ򵭽Ҥ뤿
-  buf.gsub!(/\\\$/, " <dollar> ")
-  
-  re_inlinemath = /\$(.*?)\$/      # 饤Υѥ
-  re_reference = /(\\ref\{.*?\})/  # \ref{*} Υѥ
-  re_toalign = /\\\\/              # alignĶذܹԤѥ
-  re_tag = /\\tag\{(.*?)\}/        # \tag{*} Υѥ
+  re_inlinemath = /\$(.*?)\$/  # 饤
+  re_toalign = /\\\\/  # alignĶذܹԤ
+  re_tag = /\\tag\{(.*?)\}/  # \tag{*}
+  re_reference = /(\\ref\{.*?\})/  # \ref{*}
+  re_cite = /(\\cite\{.*?\})/ # \cite{*}
   
   inlineEquations = Array.new  # Ǽ
   
   # ˳Ǽ
   inlineEquations << buf.scan(re_inlinemath)
   inlineEquations << buf.scan(re_reference)
+  inlineEquations << buf.scan(re_cite)
   
-  # ͥȤ줿եåȤˤʣǤ
   inlineEquations.flatten!.uniq!
   
-  #  |md5| ִ
+  # |md5| ִ
   buf.gsub!(re_inlinemath){ "|#{Digest::MD5.hexdigest($1)}|" }
-  
-  # \ref{*}  |md5| ִ
-  buf.gsub!(re_reference){ "|#{Digest::MD5.hexdigest($1)}|" }
+  buf.gsub!(re_reference){ " |#{Digest::MD5.hexdigest($1)}| " }
+  buf.gsub!(re_cite){ " |#{Digest::MD5.hexdigest($1)}| " }
   
   # бreStructuredTextǸ˽
-  # ʥ饤ο֤
-  n = inlineEquations.length
-  i = 0
-  while i < n
-    # ļФ
-    inEquation = inlineEquations.pop
-    if (inEquation =~ re_tag) then
+  while inlineEquations.first
+    equation = inlineEquations.shift
+    case equation
+    when re_tag
       # \tag{*}  $...$ ĶǻȤʤΤǿˤ
-      buf << "\n.. |" + Digest::MD5.hexdigest(inEquation) + "| raw:: latex\n\n"
-      buf << "  $" + inEquation.gsub(re_tag) { "(" + $1 + ")" } + "$\n\n\n"     
-    elsif (inEquation =~ re_toalign) then
-      #  \\ ޤΤ align Ķˤ
-      # 顼ˤʤ礬Τ & ϼ 
-      buf << "\n.. |" + Digest::MD5.hexdigest(inEquation) + "| raw:: latex\n\n"
-      buf << "  \\begin{align*}" + inEquation.gsub(/&/,"") + "\\end{align*}\n\n\n"
+      buf << "\n.. |#{Digest::MD5.hexdigest(equation)}| raw:: latex\n\n"
+      buf << "   $" + equation.gsub(re_tag) { "(" + $1 + ")" } + "$\n\n\n"
+    when re_toalign
+      #  \\ ޤΤ align Ķˤ & ϼ 
+      buf << "\n.. |" + Digest::MD5.hexdigest(equation) + "| raw:: latex\n\n"
+      buf << "   \\begin{align*}" + equation.gsub(/&/,"") + "\\end{align*}\n\n\n"
+    when re_reference
+      buf << "\n.. |#{Digest::MD5.hexdigest(equation)}| raw:: latex\n\n   #{equation}\n\n\n"
     else
-      # ¾ϤΤޤ
-      buf << "\n.. |" + Digest::MD5.hexdigest("#{inEquation}") + "| raw:: latex\n\n"
-      buf << "  $#{inEquation}$\n\n\n"
+      buf << "\n.. |#{Digest::MD5.hexdigest(equation)}| raw:: latex\n\n   $#{equation}$\n\n\n"
     end
-    i += 1
   end
   
-  # <dollar>  $ ִ
-  buf.gsub!(/ <dollar> /, "\$")
-  
-  return buf
+  buf.gsub!(/ <dollar> /, "\$")  # <dollar>  $ ִ
   
+  buf
 end
 
-
-# ==========================================================
-# ǥץ쥤<tex>...</tex>ִ᥽å
-# ==========================================================
-
+# ǥץ쥤ǥ쥯ƥ
 class DisplayMathDiv
   attr_accessor :tag, :matter
   # 
@@ -86,15 +70,15 @@ class DisplayMathDiv
   end
 end
 
+# ǥץ쥤<tex>...</tex>ˤִ
 def display_math(buf)
-  
   # tex   align* Ķ
   re_tex = /<tex>(.*?)<\/tex>/m
   buf.gsub!(re_tex){
     DisplayMathDiv.new("align*", $1).trans
   }
   
-  # aling   align* Ķ
+  # aling   align Ķ
   re_tex = /<align>(.*?)<\/align>/m
   buf.gsub!(re_tex){
     DisplayMathDiv.new("align", $1).trans
@@ -113,16 +97,11 @@ def display_math(buf)
   }
 =end
   
-  return buf
-  
+  buf
 end
 
-
-# ==========================================================
 # եŬڤѴ
-# ==========================================================
 def figure(buf)
-  
   # image ⤷ figure ǥ쥯ƥ֤Υѥ
   re_conv_eps = /\.\.\s+(figure|image)\s*::\s+(.*)\.(png|gif|jpg)/
   re_make_bb = /\.\.\s+(figure|image)\s*::\s+(.*)\.(pdf)/
@@ -172,22 +151,18 @@ def figure(buf)
     i += 3
   end
   
-  return buf
-  
+  buf
 end
 
-
-# ==========================================================
 # @@̿ν
-# ==========================================================
 def atat(buf)
-  
   # @@̿γƼѥ
   re_author = /@@author:\s*(.*?)\s*@@/
   re_date = /@@accept:\s*?(.+?)\s*?@@/
   re_reference = /@@reference:\s*(.*?)\s*@@/
   re_category = /@@category:\s*(.*?)\s*@@/
   re_information = /@@information:\s*(.*?)\s*@@/
+  re_id = /@@id:\s*(.*?)\s*@@/
 
   # ѥ˥ޥåʬ
   author = buf.scan(re_author).join
@@ -208,17 +183,13 @@ def atat(buf)
   buf.gsub!(re_reference, "")
   buf.gsub!(re_category, "")
   buf.gsub!(re_information, "")
+  buf.gsub!(re_id, "")
   
-  return buf
-  
+  buf
 end
 
-
-# ==========================================================
 # ¾
-# ==========================================================
 def etc(buf, style)
-  
   # footnoteϿˤ[*]  [#]
   buf.gsub!(/ \[\*\]\_ ?/, " \[#\]\_ ")
   buf.gsub!(/^\.\.\s+\[\*\]\s+/, "\.\. \[#\] ")
@@ -230,6 +201,5 @@ def etc(buf, style)
   buf.gsub!(//, "")
   buf.gsub!(//, "") if style == "hooktail"
 
-  return buf
-  
+  buf
 end
