@@ -1,7 +1,7 @@
 # :Author: SAKIMA Kimihisa
 # :Contact: sakima at hooktail.org
-# :Date: $Date: 2006/01/25 17:25:16 $
-# :Revision: $Revision: 1.3 $
+# :Date: $Date: 2007/02/24 12:53:30 $
+# :Revision: $Revision: 1.4 $
 
 $KCODE = "EUC"
 
@@ -56,7 +56,7 @@ def preamble(buf, style)
   # hyperref ѥåΥץѹ
   buf.sub!(/\\usepackage\[colorlinks=(\w+),linkcolor=(\w+),urlcolor=(\w+)\]\{hyperref\}/){
     "\\usepackage\[dvipdfm,bookmarks=true,bookmarksnumbered=true,pdfstartview=\{FitH -32768\}," +
-    "colorlinks=#{$1},linkcolor=#{$2},urlcolor=#{$3}" +
+    "colorlinks=#{$1},linkcolor=#{$2},urlcolor=#{$3},citecolor=#{$3}" +
     "\]\{hyperref\}" +
     "\\ifnum 42146=\\euc\"A4A2 \\AtBeginDvi\{\\special\{pdf:tounicode EUC-UCS2\}\}\\else" +
     "\\AtBeginDvi\{\\special\{pdf:tounicode 90ms-RKSJ-UCS2\}\}\\fi  %\""
@@ -100,10 +100,27 @@ def texbody(buf, style)
   end
 
   # \end{quote} \end{itemize} θβԤ
+  buf.gsub!(/(^\\begin\{quote\}).*?\n/){ $1 }
   buf.gsub!(/(^\\end\{quote\}).*?\n/){ $1 }
   buf.gsub!(/(^\\end\{itemize\}).*?\n/){ $1 }
   buf.gsub!(/(^\\end\{list\}).*?\n/){ $1 }
-
+  
+  # ;ʬʶ
+  buf.gsub!(/ ?([]) ?/){ $1 }
+  buf.gsub!(/ ?(\\ref\{.*?\}) ?/){ $1 }
+  buf.gsub!(/ ?(\$\\ref\{.*?\}\$) ?/){ $1 }
+  
+=begin
+  # ֹĤʤ
+  DO_NOT_NUMBERING = [
+  'ռ',
+  'acknowledgment'
+  ]
+  buf.gsub!(/\\chapter\{(#{DO_NOT_NUMBERING[0]})\}/){
+    "\chapter*{#{$1}}\n\addcontentsline{toc}{chapter}{#{$1}}"
+  }
+=end
+  
   # \href{...} % 򥨥
   buf = buf.gsub(/\\href\{(.*?)\}/){
     "\\href\{" + $1.gsub(/%/, "\\%") + "\}"
@@ -116,9 +133,11 @@ def texbody(buf, style)
   
   if style == "thesis"
     buf.sub!(/\\begin\{center\}.*?\\begin\{tabularx\}\{\\docinfowidth\}\{lX\}.*?\\end\{tabularx\}.*?\\end\{center\}.*?\\setlength\{\\locallinewidth\}\{\\linewidth\}.*?\\tableofcontents.*?\\bigskip/m, "\\frontmatter\n\\tableofcontents\n\\mainmatter")
-    buf.gsub!(/\\section/, "\\chapter")
-    buf.gsub!(/\\subsection/, "\\section")
-    buf.gsub!(/\\subsubsection/, "\\subsection")
+    buf.gsub!(/\\section\{ռ\}/, '\chapter*{ռ}\addcontentsline{toc}{chapter}{ռ}')
+    buf.gsub!(/\\section/, '\chapter')
+    buf.gsub!(/\\subsection/, '\section')
+    buf.gsub!(/\\subsubsection/, '\subsection')
+    buf.gsub!(/ ?\$(\\cite\{.*?\})\$ ?/){ "~#{$1}" }
   end
   
   return buf
